Welcome to NEP29 Calculator's documentation!
======================================

.. mdinclude:: ../README.md

Contents
========

.. toctree::
   :maxdepth: 1

   installation
   usage
   modules
   contributing

   AUTHORS
   HISTORY

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
